ElementDeclData

Struct ElementDeclData 

pub struct ElementDeclData {
Show 25 fields pub name: Option<NameId>, pub target_namespace: Option<NameId>, pub ref_name: Option<QNameRef>, pub type_ref: Option<TypeRefResult>, pub inline_type: Option<Box<TypeFrameResult>>, pub substitution_group: Vec<QNameRef>, pub default_value: Option<String>, pub fixed_value: Option<String>, pub nillable: bool, pub is_abstract: bool, pub min_occurs: u32, pub max_occurs: Option<u32>, pub block: DerivationSet, pub final_derivation: DerivationSet, pub form: Option<String>, pub id: Option<String>, pub alternatives: Vec<AlternativeResult>, pub identity_constraints: Vec<IdentityConstraintKey>, pub pending_ic_refs: Vec<(IdentityKind, QNameRef, Option<SourceRef>)>, pub annotation: Option<Annotation>, pub source: Option<SourceRef>, pub resolved_type: Option<TypeKey>, pub resolved_ref: Option<ElementKey>, pub resolved_substitution_groups: Vec<ElementKey>, pub deferred_type_error: Option<DeferredSrcResolve>,
}
Placeholder for ElementDecl (defined in schema/decl.rs)

Fields

name: Option<NameId>target_namespace: Option<NameId>ref_name: Option<QNameRef>type_ref: Option<TypeRefResult>inline_type: Option<Box<TypeFrameResult>>substitution_group: Vec<QNameRef>default_value: Option<String>fixed_value: Option<String>nillable: boolis_abstract: boolmin_occurs: u32max_occurs: Option<u32>block: DerivationSetfinal_derivation: DerivationSetform: Option<String>id: Option<String>alternatives: Vec<AlternativeResult>identity_constraints: Vec<IdentityConstraintKey>pending_ic_refs: Vec<(IdentityKind, QNameRef, Option<SourceRef>)>

XSD 1.1: pending identity constraint @ref references (resolved in resolve_all_references)

annotation: Option<Annotation>source: Option<SourceRef>resolved_type: Option<TypeKey>

Resolved type key (from type_ref or inline_type)

resolved_ref: Option<ElementKey>

Resolved element reference (for element refs)

resolved_substitution_groups: Vec<ElementKey>

Resolved substitution group head elements

deferred_type_error: Option<DeferredSrcResolve>

Deferred src-resolve error for an explicit type attribute whose target is missing. Reported when this element declaration is selected for validation, before any xs:anyType fallback.