pub struct ActiveConfig {
pub state_id: StateId,
pub counters: Box<[u32]>,
}Expand description
A single NFA configuration with counter values.
Represents one “thread” in the NFA simulation where each counter has a specific value. Two configs at the same state but different counter values are distinct.
Fields
state_id: StateIdcounters: Box<[u32]>Implementations