CompileContext

Struct CompileContext 

pub struct CompileContext<'a> {
    pub schema_set: &'a SchemaSet,
    pub target_namespace: Option<NameId>,
    /* private fields */
}
Context for NFA compilation

Provides access to the schema set for resolving references during compilation.

Fields

schema_set: &'a SchemaSet

Reference to the schema set for resolving references

target_namespace: Option<NameId>

Target namespace for the content model being compiled

Implementations

Source

impl<'a> CompileContext<'a>

pub fn new(schema_set: &'a SchemaSet, target_namespace: Option<NameId>) -> Self

Create a new compilation context

pub fn new_for_upa( schema_set: &'a SchemaSet, target_namespace: Option<NameId>, ) -> Self

Create a compilation context with UPA occurrence-bound capping enabled.

pub fn compile_particle( &mut self, particle: &ParticleResult, ) -> NfaCompileResult<NfaTable>

Compile a particle to an NFA table

This is the main entry point for compiling a content model particle.

pub fn compile_model_group( &mut self, group: &ModelGroupDefResult, ) -> NfaCompileResult<NfaTable>

Compile a model group to an NFA table

Used for compiling named groups (xs:group).