pub struct NamespaceNode {
pub prefix: NameId,
pub namespace_uri: NameId,
pub next: NsRef,
}Expand description
A single namespace binding in a linked chain — 12 bytes.
Each element that declares namespace bindings stores an NsRef head
that points to the first NamespaceNode in a chain. The next field
links to the following binding (or NsRef::NULL for end-of-chain).
Fields
prefix: NameIdnamespace_uri: NameIdnext: NsRefImplementations