parse_schema

Function parse_schema 

pub fn parse_schema(
    xml: &[u8],
    base_uri: &str,
    schema_set: &mut SchemaSet,
) -> SchemaResult<DocumentId>
Parse an XSD schema document

This is the main entry point for parsing XSD documents.

Arguments

  • xml - Raw XML bytes of the schema document
  • base_uri - Base URI for this document (for error messages and include resolution)
  • schema_set - Schema set to add the parsed document to

Returns

The document ID of the parsed schema, or an error if parsing failed.