pub fn validate_xsd_version_attribute(
attr_name: &str,
element_name: &str,
ctx: &ValidationContext,
) -> SchemaResult<()>Expand description
Validate that an attribute is allowed in the current XSD version
pub fn validate_xsd_version_attribute(
attr_name: &str,
element_name: &str,
ctx: &ValidationContext,
) -> SchemaResult<()>Validate that an attribute is allowed in the current XSD version