pub fn create_implicit_annotation(
attrs: Vec<ForeignAttribute>,
source: Option<SourceRef>,
) -> AnnotationExpand description
Implicit annotation - created from foreign attributes on schema elements
When a schema element has foreign attributes but no explicit xs:annotation, an implicit annotation is created to hold them.