pub struct InlineAssemblyStats {
pub element_inline_types: usize,
pub attribute_inline_types: usize,
pub simple_type_inline_derivations: usize,
pub complex_type_inline_derivations: usize,
pub model_group_inline_types: usize,
pub attribute_group_inline_types: usize,
pub complex_type_attribute_inline_types: usize,
pub total_inline_types: usize,
}Expand description
Statistics from the inline type assembly pass
Fields
element_inline_types: usizeNumber of element inline types assembled
attribute_inline_types: usizeNumber of attribute inline types assembled
simple_type_inline_derivations: usizeNumber of simple type base/item/member inline types assembled
complex_type_inline_derivations: usizeNumber of complex type base type inline types assembled
model_group_inline_types: usizeNumber of inline types in model group particles assembled
attribute_group_inline_types: usizeNumber of inline types in attribute groups assembled
complex_type_attribute_inline_types: usizeNumber of inline types in complex type attributes assembled
total_inline_types: usizeTotal inline types assembled