pub struct DerivationSet(/* private fields */);Expand description
Derivation control flags (for final, block attributes)
Implementations
Sourceimpl DerivationSet
impl DerivationSet
pub const EXTENSION: Self
pub const RESTRICTION: Self
pub const LIST: Self
pub const UNION: Self
pub const SUBSTITUTION: Self
Sourcepub const ELEMENT_BLOCK: Self
pub const ELEMENT_BLOCK: Self
Element-relevant block bits (LIST and UNION are not meaningful for elements)
Sourceimpl DerivationSet
impl DerivationSet
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl DerivationSet
impl DerivationSet
Sourcepub const fn iter(&self) -> Iter<DerivationSet>
pub const fn iter(&self) -> Iter<DerivationSet>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DerivationSet>
pub const fn iter_names(&self) -> IterNames<DerivationSet>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl DerivationSet
impl DerivationSet
Sourcepub fn restriction() -> Self
pub fn restriction() -> Self
Create a DerivationSet with only RESTRICTION
Sourcepub fn contains_extension(&self) -> bool
pub fn contains_extension(&self) -> bool
Check if extension is blocked/final
Sourcepub fn contains_restriction(&self) -> bool
pub fn contains_restriction(&self) -> bool
Check if restriction is blocked/final
Sourcepub fn contains_list(&self) -> bool
pub fn contains_list(&self) -> bool
Check if list derivation is blocked/final
Sourcepub fn contains_union(&self) -> bool
pub fn contains_union(&self) -> bool
Check if union derivation is blocked/final
Sourcepub fn contains_substitution(&self) -> bool
pub fn contains_substitution(&self) -> bool
Check if substitution is blocked
Sourcepub fn element_block_mask(self) -> Self
pub fn element_block_mask(self) -> Self
Mask to only element-relevant block bits (extension, restriction, substitution).
LIST and UNION are simple-type derivation methods and have no meaning in element
block attributes. Per the spec, element block="#all" means {extension, restriction, substitution} only.