SequenceType

Struct SequenceType 

pub struct SequenceType {
    pub item_type: ItemType,
    pub cardinality: XmlTypeCardinality,
}
XPath2 sequence type

Describes the expected type of a sequence of items. Used for type checking, type matching, and conversions.

Fields

item_type: ItemType

The item type

cardinality: XmlTypeCardinality

The occurrence indicator

Implementations

Source

impl SequenceType

pub fn new(item_type: ItemType, cardinality: XmlTypeCardinality) -> Self

Create a new sequence type

pub fn one(item_type: ItemType) -> Self

Create a sequence type for exactly one item

pub fn optional(item_type: ItemType) -> Self

Create a sequence type for zero or one items

pub fn plus(item_type: ItemType) -> Self

Create a sequence type for one or more items

pub fn star(item_type: ItemType) -> Self

Create a sequence type for zero or more items

pub fn empty() -> Self

Create empty-sequence() type

This only matches empty sequences (zero items).

pub fn is_empty_sequence(&self) -> bool

Check if this is the empty-sequence() type

pub fn any() -> Self

Create item()* - any sequence

pub fn item() -> Self

Create item() - exactly one item

pub fn node() -> Self

Create node() - exactly one node

pub fn nodes() -> Self

Create node()* - sequence of nodes

pub fn string() -> Self

xs:string

pub fn string_optional() -> Self

xs:string?

pub fn boolean() -> Self

xs:boolean

pub fn integer() -> Self

xs:integer

pub fn integer_optional() -> Self

xs:integer?

pub fn decimal() -> Self

xs:decimal

pub fn double() -> Self

xs:double

pub fn double_optional() -> Self

xs:double?

pub fn any_atomic() -> Self

xs:anyAtomicType

pub fn any_atomic_optional() -> Self

xs:anyAtomicType?

pub fn any_atomic_star() -> Self

xs:anyAtomicType*

pub fn datetime() -> Self

xs:dateTime

pub fn date() -> Self

xs:date

pub fn time() -> Self

xs:time

pub fn duration() -> Self

xs:duration

pub fn qname() -> Self

xs:QName

pub fn any_uri() -> Self

xs:anyURI

pub fn type_code(&self) -> XmlTypeCode

Get the type code for the item type

pub fn is_node(&self) -> bool

Check if this sequence type matches nodes

pub fn is_atomic(&self) -> bool

Check if this sequence type matches atomic values

pub fn is_numeric(&self) -> bool

Check if this sequence type is numeric (decimal, float, double, integer types)

pub fn allows_empty(&self) -> bool

Check if this sequence type allows empty sequences

pub fn matches_sequence<N: DomNavigator>( &self, items: &[XmlItem<N>], ctx: &XPathContext<'_>, ) -> bool

Check if a sequence of items matches this sequence type.

Validates both cardinality and item type for each item in the sequence.