XmlAtomicValue

Enum XmlAtomicValue 

pub enum XmlAtomicValue {
Show 22 variants String(String), Boolean(bool), Decimal(Decimal), Integer(BigInt), Float(f32), Double(f64), DateTime(DateTimeValue), Date(DateValue), Time(TimeValue), Duration(DurationValue), GYearMonth(GYearMonthValue), GYear(GYearValue), GMonthDay(GMonthDayValue), GDay(GDayValue), GMonth(GMonthValue), YearMonthDuration(YearMonthDurationValue), DayTimeDuration(DayTimeDurationValue), HexBinary(Vec<u8>), Base64Binary(Vec<u8>), AnyUri(String), QName(QualifiedName), Notation(QualifiedName),
}
Atomic XSD value types

This enum holds the actual parsed values for atomic XSD types. For complex types like date/time, we use structured representations.

Variants



String(String)

xs:string and derived types



Boolean(bool)

xs:boolean



Decimal(Decimal)

xs:decimal



Integer(BigInt)

xs:integer and derived integer types



Float(f32)

xs:float



Double(f64)

xs:double



DateTime(DateTimeValue)

xs:dateTime



Date(DateValue)

xs:date



Time(TimeValue)

xs:time



Duration(DurationValue)

xs:duration



GYearMonth(GYearMonthValue)

xs:gYearMonth



GYear(GYearValue)

xs:gYear



GMonthDay(GMonthDayValue)

xs:gMonthDay



GDay(GDayValue)

xs:gDay



GMonth(GMonthValue)

xs:gMonth



YearMonthDuration(YearMonthDurationValue)

xs:yearMonthDuration (XSD 1.1)



DayTimeDuration(DayTimeDurationValue)

xs:dayTimeDuration (XSD 1.1)



HexBinary(Vec<u8>)

xs:hexBinary



Base64Binary(Vec<u8>)

xs:base64Binary



AnyUri(String)

xs:anyURI



QName(QualifiedName)

xs:QName



Notation(QualifiedName)

xs:NOTATION

Implementations

Source

impl XmlAtomicValue

pub fn type_code(&self) -> XmlTypeCode

Get the type code for this atomic value

pub fn primitive_type(&self) -> PrimitiveTypeCode

Get the primitive type code for this atomic value