pub fn error(
constraint: &'static str,
message: impl Into<String>,
location: Option<SourceLocation>,
) -> ValidationErrorExpand description
Create a validation error with the given constraint code and message
pub fn error(
constraint: &'static str,
message: impl Into<String>,
location: Option<SourceLocation>,
) -> ValidationErrorCreate a validation error with the given constraint code and message