from_facet_error

Function from_facet_error 

pub fn from_facet_error(
    constraint: &'static str,
    err: FacetError,
    location: Option<SourceLocation>,
) -> ValidationError
Convert a facet error to an instance validation error

Use this when a FacetError needs to be reported with a specific cvc-* code. Consider using facet_constraint_code() to get the appropriate code.