from_value_error

Function from_value_error 

pub fn from_value_error(
    constraint: &'static str,
    err: ValidationError,
    location: Option<SourceLocation>,
) -> ValidationError
Convert a type validation error to an instance validation error

Use this when a types::validators::ValidationError needs to be reported with a specific cvc-* constraint code.