pub enum ValidationAttempted {
None,
Partial,
Full,
}Expand description
How much validation was attempted on a node (PSVI [validation attempted])
Variants
None
No validation was attempted
Partial
Some but not all descendants were validated
Full
Full validation was performed on this node and all descendants