pub struct ExternalVar {
pub name: QualifiedName,
pub slot: VarSlotId,
}Expand description
Information about an external variable declared at compile time.
External variables are those declared by the user (via compile_with_vars)
as opposed to variables introduced by the expression itself (like for $x in ...).
Fields
name: QualifiedNameThe qualified name of the variable
slot: VarSlotIdThe slot ID for storing the variable’s value