string_value

Function string_value 

pub fn string_value(value: &XmlValue) -> String
Get the string value of an XmlValue.

For atomic values, this returns the canonical string representation. For union values, this unwraps and gets the string value. For list values, this joins the item strings with spaces.

Arguments

  • value - The value to convert to string

Returns

The string representation of the value