XPathValue

Enum XPathValue 

pub enum XPathValue<N: DomNavigator> {
    Empty,
    Item(XmlItem<N>),
    Sequence(Vec<XmlItem<N>>),
}
XPath value representing a function result.

This enum represents the result of evaluating an XPath expression or function. It can be empty, a single item, or a sequence of items.

Variants



Empty

Empty sequence



Item(XmlItem<N>)

Single item (node or atomic value)



Sequence(Vec<XmlItem<N>>)

Sequence of items (materialized)

Implementations

Source

impl<N: DomNavigator> XPathValue<N>

pub fn empty() -> Self

Create an empty value

pub fn from_item(item: XmlItem<N>) -> Self

Create a value from a single item

pub fn from_atomic(value: XmlValue) -> Self

Create a value from an atomic XmlValue

pub fn from_node(node: N) -> Self

Create a value from a node

pub fn from_sequence(items: Vec<XmlItem<N>>) -> Self

Create a value from a sequence of items

pub fn boolean(b: bool) -> Self

Create a boolean value

pub fn string(s: impl Into<String>) -> Self

Create a string value

pub fn integer(i: impl Into<BigInt>) -> Self

Create an integer value

pub fn decimal(d: Decimal) -> Self

Create a decimal value

pub fn double(d: f64) -> Self

Create a double value

pub fn is_empty(&self) -> bool

Check if this value is empty

pub fn len(&self) -> usize

Get the count of items

pub fn is_single(&self) -> bool

Check if this is a single item

pub fn into_vec(self) -> Vec<XmlItem<N>>

Convert to a Vec of items

pub fn as_slice(&self) -> &[XmlItem<N>]

Get a reference to items as a slice

pub fn first(&self) -> Option<&XmlItem<N>>

Try to get the first item

pub fn as_str(&self) -> Option<String>

Try to extract a string from a single atomic item.

Returns None if:

  • The value is empty
  • The value is a sequence
  • The item is a node (not atomic)
  • The atomic value is not a string type
pub fn as_bool(&self) -> Option<bool>

Try to extract a boolean from a single atomic item.

Returns None if the value is not a single atomic boolean.

pub fn as_f64(&self) -> Option<f64>

Try to extract a double from a single atomic item.

Returns None if the value is not a single atomic numeric value.

pub fn as_integer(&self) -> Option<BigInt>

Try to extract an integer from a single atomic item.

Returns None if the value is not a single atomic integer.