DynamicFunctionSignature

Struct DynamicFunctionSignature 

pub struct DynamicFunctionSignature {
    pub namespace: Arc<str>,
    pub local_name: Arc<str>,
    pub arity: FunctionArity,
    pub param_types: Vec<SequenceType>,
    pub return_type: SequenceType,
}
Function signature with owned strings for external registration.

Unlike FunctionSignature which uses &'static str for built-in functions, this type owns its strings, allowing dynamic registration of custom functions.

Fields

namespace: Arc<str>

The function namespace URI.

local_name: Arc<str>

The local name of the function.

arity: FunctionArity

The arity specification.

param_types: Vec<SequenceType>

Parameter types (may be shorter than actual args for variadic functions).

return_type: SequenceType

Return type.

Implementations

Source

impl DynamicFunctionSignature

pub fn new( namespace: impl Into<Arc<str>>, local_name: impl Into<Arc<str>>, param_types: Vec<SequenceType>, return_type: SequenceType, ) -> Self

Create a new dynamic signature with exact arity.

pub fn variadic( namespace: impl Into<Arc<str>>, local_name: impl Into<Arc<str>>, min_args: usize, param_types: Vec<SequenceType>, return_type: SequenceType, ) -> Self

Create a variadic function signature.

pub fn range( namespace: impl Into<Arc<str>>, local_name: impl Into<Arc<str>>, min_args: usize, max_args: usize, param_types: Vec<SequenceType>, return_type: SequenceType, ) -> Self

Create a function signature with range arity.

pub fn matches_arity(&self, count: usize) -> bool

Check if this signature matches the given arity.