eval_function

Function eval_function 

pub fn eval_function<N: DomNavigator>(
    id: FunctionId,
    context: &mut DynamicContext<'_, N>,
    args: Vec<XPathValue<N>>,
) -> Result<XPathValue<N>, XPathError>
Evaluate a function by its ID.

This is the main dispatch function that routes to the appropriate function implementation based on the FunctionId.