ceiling

Function ceiling 

pub fn ceiling<N: DomNavigator>(
    _context: &mut DynamicContext<'_, N>,
    args: Vec<XPathValue<N>>,
) -> Result<XPathValue<N>, XPathError>
Implements fn:ceiling - returns the smallest integer greater than or equal to the argument.

The function preserves the numeric type of the input.