Module sequence

Module sequence 

XPath 2.0 sequence functions.

This module implements sequence functions from the XPath 2.0 specification:

  • fn:index-of
  • fn:remove
  • fn:insert-before
  • fn:subsequence
  • fn:unordered
  • fn:deep-equal

Functions

deep_equal
Implements fn:deep-equal - tests whether two sequences are deep-equal.
distinct_values
Implements fn:distinct-values - returns unique values from a sequence.
exactly_one
Implements fn:exactly-one - returns the argument if it contains exactly one item.
index_of
Implements fn:index-of - returns positions of matching items in a sequence.
insert_before
Implements fn:insert-before - inserts items into a sequence.
one_or_more
Implements fn:one-or-more - returns the argument if it contains one or more items.
remove
Implements fn:remove - removes an item from a sequence at a given position.
reverse
Implements fn:reverse - reverses the order of items in a sequence.
subsequence
Implements fn:subsequence - returns a contiguous subsequence.
unordered
Implements fn:unordered - returns the sequence in implementation-defined order.
zero_or_one
Implements fn:zero-or-one - returns the argument if it contains zero or one items.