remove

Function remove 

pub fn remove<N: DomNavigator>(
    _context: &mut DynamicContext<'_, N>,
    args: Vec<XPathValue<N>>,
) -> Result<XPathValue<N>, XPathError>
Implements fn:remove - removes an item from a sequence at a given position.

Returns a new sequence with the item at the specified position removed. If $position is less than 1 or greater than the length of $target, the sequence is returned unchanged.