pub struct FunctionSignature {
pub namespace: &'static str,
pub local_name: &'static str,
pub arity: FunctionArity,
pub param_types: Vec<SequenceType>,
pub return_type: SequenceType,
}Expand description
Function signature describing parameter and return types
Fields
namespace: &'static strThe function namespace URI
local_name: &'static strThe local name of the function
arity: FunctionArityThe arity specification
param_types: Vec<SequenceType>Parameter types (may be shorter than actual args for variadic functions)
return_type: SequenceTypeReturn type
Implementations
Sourceimpl FunctionSignature
impl FunctionSignature
Sourcepub fn new(
namespace: &'static str,
local_name: &'static str,
param_types: Vec<SequenceType>,
return_type: SequenceType,
) -> Self
pub fn new( namespace: &'static str, local_name: &'static str, param_types: Vec<SequenceType>, return_type: SequenceType, ) -> Self
Create a new function signature with exact arity
Sourcepub fn variadic(
namespace: &'static str,
local_name: &'static str,
min_args: usize,
param_types: Vec<SequenceType>,
return_type: SequenceType,
) -> Self
pub fn variadic( namespace: &'static str, local_name: &'static str, min_args: usize, param_types: Vec<SequenceType>, return_type: SequenceType, ) -> Self
Create a function signature with variadic arity
Sourcepub fn range(
namespace: &'static str,
local_name: &'static str,
min_args: usize,
max_args: usize,
param_types: Vec<SequenceType>,
return_type: SequenceType,
) -> Self
pub fn range( namespace: &'static str, local_name: &'static str, min_args: usize, max_args: usize, param_types: Vec<SequenceType>, return_type: SequenceType, ) -> Self
Create a function signature with range arity
Sourcepub fn matches_arity(&self, count: usize) -> bool
pub fn matches_arity(&self, count: usize) -> bool
Check if this signature matches the given arity
Sourcepub fn param_type(&self, index: usize) -> SequenceType
pub fn param_type(&self, index: usize) -> SequenceType
Get the expected type for a parameter at the given index
For variadic functions, if the index exceeds the param_types length, returns the last parameter type (if any) or item()*.