XPathComparer

Struct XPathComparer 

pub struct XPathComparer;
A comparer that sorts XPath nodes in document order.

This comparer implements the XPath document order comparison for nodes. It is used to sort node sequences returned by XPath operations like union, intersect, and except.

Panics

Panics if either item is not a node (i.e., is an atomic value).

Implementations

Source

impl XPathComparer

pub fn new() -> Self

Creates a new XPathComparer.

pub fn try_compare<N: DomNavigator>( &self, x: &XmlItem<N>, y: &XmlItem<N>, ) -> Result<Ordering, XPathError>

Fallible comparison of two XmlItems in document order.

Returns an error if either item is not a node.