XmlItem

Enum XmlItem 

pub enum XmlItem<N: DomNavigator> {
    Node(N),
    Atomic(XmlValue),
}
XPath item (node or atomic value).

Variants



Node(N)



Atomic(XmlValue)

Implementations

Source

impl<N: DomNavigator> XmlItem<N>

pub fn is_node(&self) -> bool

Check if this item is a node.

pub fn is_atomic(&self) -> bool

Check if this item is an atomic value.

pub fn as_node(&self) -> Option<&N>

Try to get a reference to the node.

pub fn as_atomic(&self) -> Option<&XmlValue>

Try to get a reference to the atomic value.

pub fn as_str(&self) -> Option<String>

Try to extract a string from an atomic item.

pub fn as_bool(&self) -> Option<bool>

Try to extract a boolean from an atomic item.

pub fn as_f64(&self) -> Option<f64>

Try to extract a double from an atomic item.

pub fn as_integer(&self) -> Option<BigInt>

Try to extract an integer from an atomic item.