Token

Enum Token 

pub enum Token {
Show 95 variants StringLiteral(String), IntegerLiteral(String), DecimalLiteral(String), DoubleLiteral(String), NCName(String), QName(String), QNameNillable(String), VarName { prefix: String, local: String, }, For, In, Return, If, Then, Else, Some, Every, Satisfies, And, Or, To, Div, IDiv, Mod, Union, Except, Intersect, InstanceOf, TreatAs, CastAs, CastableAs, Element, Attribute, Text, Comment, Node, DocumentNode, ProcessingInstruction, SchemaElement, SchemaAttribute, Item, EmptySequence, AxisChild, AxisDescendant, AxisAttribute, AxisSelf, AxisDescendantOrSelf, AxisFollowingSibling, AxisFollowing, AxisParent, AxisAncestor, AxisPrecedingSibling, AxisPreceding, AxisAncestorOrSelf, AxisNamespace, Eq, Ne, Lt, Le, Gt, Ge, Is, OccurrenceZeroOrOne, OccurrenceOneOrMore, OccurrenceZeroOrMore, DoublePeriod, DoubleSlash, NotEquals, LessEquals, GreaterEquals, DoubleLess, DoubleGreater, LParen, RParen, LBracket, RBracket, Comma, Colon, At, Dollar, Slash, SlashOnly, Pipe, Plus, Minus, Minus10, Plus10, Minus20, Plus20, Star, Equals, LessThan, GreaterThan, Question, Dot, Eof,
}
Token type for XPath 2.0 expressions.

Variants



StringLiteral(String)



IntegerLiteral(String)



DecimalLiteral(String)



DoubleLiteral(String)



NCName(String)



QName(String)



QNameNillable(String)

QName followed by “?” in kind test context, meaning nillable type. Used to resolve shift/reduce conflict in element(name, type?).



VarName

Fields

prefix: String
local: String


For



In



Return



If



Then



Else



Some



Every



Satisfies



And



Or



To



Div



IDiv



Mod



Union



Except



Intersect



InstanceOf



TreatAs



CastAs



CastableAs



Element



Attribute



Text



Comment



Node



DocumentNode



ProcessingInstruction



SchemaElement



SchemaAttribute



Item



EmptySequence



AxisChild



AxisDescendant



AxisAttribute



AxisSelf



AxisDescendantOrSelf



AxisFollowingSibling



AxisFollowing



AxisParent



AxisAncestor



AxisPrecedingSibling



AxisPreceding



AxisAncestorOrSelf



AxisNamespace



Eq



Ne



Lt



Le



Gt



Ge



Is



OccurrenceZeroOrOne



OccurrenceOneOrMore



OccurrenceZeroOrMore



DoublePeriod



DoubleSlash



NotEquals



LessEquals



GreaterEquals



DoubleLess



DoubleGreater



LParen



RParen



LBracket



RBracket



Comma



Colon



At



Dollar



Slash



SlashOnly

“/” when NOT followed by something that starts a path step. Used to resolve the shift/reduce conflict for standalone “/” (root).



Pipe



Plus



Minus



Minus10



Plus10



Minus20



Plus20



Star



Equals



LessThan



GreaterThan



Question



Dot



Eof