parse_expr

Function parse_expr 

pub fn parse_expr(
    input: &str,
    arena: &mut AstArena,
) -> Result<AstNodeId, ParseError>
Parse an XPath expression and return just the root node ID.

This is a convenience function when you only need the arena and root.