Quantified expression support for XPath evaluation.
This module implements XPath 2.0 quantified expressions:
some $x in ... satisfies ...every $x in ... satisfies ...
Functions
- every
- Check if every item in the sequence satisfies the condition.
- every_
true - Check if all values in the sequence are true.
- every_
with - Check if every value in the sequence matches a predicate.
- some
- Check if some item in the sequence satisfies the condition.
- some_
true - Check if the sequence contains at least one true value.
- some_
with - Check if some value in the sequence matches a predicate.