except_nodes

Function except_nodes 

pub fn except_nodes<N: DomNavigator + Clone>(
    left: Vec<XmlItem<N>>,
    right: Vec<XmlItem<N>>,
) -> Result<Vec<XmlItem<N>>, XPathError>
Compute the difference of two node sequences (left except right).

Returns nodes that appear in left but not in right, sorted in document order.

XPath Semantics

The except operator returns all nodes that are in the first operand but not in the second operand, in document order.

Errors

Returns XPTY0004 if either sequence contains non-node items.