intersect_nodes

Function intersect_nodes 

pub fn intersect_nodes<N: DomNavigator + Clone>(
    left: Vec<XmlItem<N>>,
    right: Vec<XmlItem<N>>,
) -> Result<Vec<XmlItem<N>>, XPathError>
Compute the intersection of two node sequences.

Returns nodes that appear in both sequences, sorted in document order.

XPath Semantics

The intersect operator returns all nodes that are in both operands, in document order.

Errors

Returns XPTY0004 if either sequence contains non-node items.