union_atomic_values

Function union_atomic_values 

pub fn union_atomic_values(
    left: Vec<XmlValue>,
    right: Vec<XmlValue>,
) -> Vec<XmlValue>
Compute the union of two atomic value sequences (deduplicates by value equality).

Note: This is NOT the XPath | operator (which is node-only). This is for internal use with atomic value sequences.