pub fn node_ref_from(page: u32, slot: u32) -> u32
Constructs a flat node index from a page number and slot.
Panics if slot >= PAGE_SIZE, which would alias bits into the page portion.
slot >= PAGE_SIZE