Embedded schema assets
Contains well-known schemas embedded as static binary data for offline use without network access.
Constants
- XLINK_
NAMESPACE - Well-known namespace URI for the xlink: prefix
- XLINK_
XSD - Embedded xlink.xsd schema defining XLink attributes (xlink:type, xlink:href, etc.). Source: http://www.w3.org/XML/2008/06/xlink.xsd
- XML_
NAMESPACE - Well-known namespace URI for the xml: prefix
- XML_XSD
- Embedded xml.xsd schema defining xml:lang, xml:space, xml:base attributes. Source: http://www.w3.org/2001/xml.xsd
Functions
- get_
embedded_ schema - Get embedded schema by namespace URI
- has_
embedded_ schema - Check if a namespace has an embedded schema available