pub struct SequenceType {
pub item_type: ItemType,
pub cardinality: XmlTypeCardinality,
}Expand description
XPath2 sequence type
Describes the expected type of a sequence of items. Used for type checking, type matching, and conversions.
Fields
item_type: ItemTypeThe item type
cardinality: XmlTypeCardinalityThe occurrence indicator
Implementations
Sourceimpl SequenceType
impl SequenceType
Sourcepub fn new(item_type: ItemType, cardinality: XmlTypeCardinality) -> Self
pub fn new(item_type: ItemType, cardinality: XmlTypeCardinality) -> Self
Create a new sequence type
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Create empty-sequence() type
This only matches empty sequences (zero items).
Sourcepub fn is_empty_sequence(&self) -> bool
pub fn is_empty_sequence(&self) -> bool
Check if this is the empty-sequence() type
Sourcepub fn string_optional() -> Self
pub fn string_optional() -> Self
xs:string?
Sourcepub fn integer_optional() -> Self
pub fn integer_optional() -> Self
xs:integer?
Sourcepub fn double_optional() -> Self
pub fn double_optional() -> Self
xs:double?
Sourcepub fn any_atomic() -> Self
pub fn any_atomic() -> Self
xs:anyAtomicType
Sourcepub fn any_atomic_optional() -> Self
pub fn any_atomic_optional() -> Self
xs:anyAtomicType?
Sourcepub fn any_atomic_star() -> Self
pub fn any_atomic_star() -> Self
xs:anyAtomicType*
Sourcepub fn type_code(&self) -> XmlTypeCode
pub fn type_code(&self) -> XmlTypeCode
Get the type code for the item type
Sourcepub fn is_numeric(&self) -> bool
pub fn is_numeric(&self) -> bool
Check if this sequence type is numeric (decimal, float, double, integer types)
Sourcepub fn allows_empty(&self) -> bool
pub fn allows_empty(&self) -> bool
Check if this sequence type allows empty sequences
Sourcepub fn matches_sequence<N: DomNavigator>(
&self,
items: &[XmlItem<N>],
ctx: &XPathContext<'_>,
) -> bool
pub fn matches_sequence<N: DomNavigator>( &self, items: &[XmlItem<N>], ctx: &XPathContext<'_>, ) -> bool
Check if a sequence of items matches this sequence type.
Validates both cardinality and item type for each item in the sequence.