pub fn atomize(value: &XmlValue) -> Result<XmlValue, XPathError>Expand description
Atomize an XmlValue, returning its atomic representation.
For atomic values, this returns a clone of the value. For union values, this unwraps and atomizes the inner value. For list values, this returns an error (multiple items).
Arguments
value- The value to atomize
Returns
Ok(XmlValue)- The atomized valueErr(XPathError)- If atomization fails