Function instance_of
Source pub fn instance_of(value: &XmlValue, target_type: XmlTypeCode) -> bool
Check if a value is an instance of a type.
This implements the XPath instance of expression.
Arguments
value - The value to check
target_type - The type to check against
Returns
true if the value matches the type, false otherwise