XPath 2.0 Parser module.
This module provides the public API for parsing XPath 2.0 expressions. It uses the LALRPOP-generated parser with a custom stateful lexer.
Modules
Structs
- ParsedX
Path - Result of parsing an XPath expression.
Enums
- Parse
Error - Error type for XPath parsing.
Functions
- parse
- Parse an XPath 2.0 expression string.
- parse_
expr - Parse an XPath expression and return just the root node ID.
- parse_
expr_ with_ mode - Parse an XPath expression with a specific mode and return just the root node ID.
- parse_
with_ mode - Parse an XPath expression with a specific mode (XPath 1.0 or 2.0).
- parse_
with_ options - Parse an XPath expression with structured options, returning
XPathErroron failure. - parse_
xpath10 - Parse an XPath expression in XPath 1.0 mode, returning
XPathErroron failure. - parse_
xpath20 - Parse an XPath expression in XPath 2.0 mode, returning
XPathErroron failure.