String operations for XPath evaluation.
This module implements XPath 2.0 string functions and normalization:
normalize-spacenormalize-unicode- Entity reference handling
- Whitespace normalization
Enums
- Unicode
Normalization Form - Unicode normalization forms.
Functions
- codepoint_
equal - Compare two strings by codepoint (ordinal comparison).
- codepoints_
to_ string - Convert a sequence of codepoints to a string.
- compare
- Compare two strings.
- concat
- Concatenate strings.
- contains
- Check if a string contains a substring.
- encode_
for_ uri - Encode a string for use in a URI per RFC 3986.
- ends_
with - Check if a string ends with a suffix.
- escape_
html_ uri - Escape a URI for use in HTML.
- iri_
to_ uri - Escape an IRI to produce a valid URI.
- is_
xml_ whitespace - Check if a character is XML whitespace.
- is_
xml_ whitespace_ str - Check if a string consists entirely of XML whitespace characters.
- lower_
case - Convert string to lowercase.
- normalize_
space - Normalize whitespace in a string (XPath fn:normalize-space).
- normalize_
string_ value - Normalize a string value with entity reference handling.
- normalize_
unicode - Normalize a string using Unicode normalization.
- starts_
with - Check if a string starts with a prefix.
- string_
join - Join strings with a separator.
- string_
length - Get the length of a string in characters.
- string_
to_ codepoints - Convert a string to a sequence of codepoints.
- substring
- Get a substring (XPath-style 1-based indexing).
- substring_
after - Get the substring after the first occurrence of a pattern.
- substring_
before - Get the substring before the first occurrence of a pattern.
- translate
- Translate characters in a string.
- upper_
case - Convert string to uppercase.